@@ -215,12 +215,15 @@ def read_star_filament_file(path, box_width, min_distance=0) -> typing.List[Fila
     sfile = star.StarFile(path)
     filaments = {}
     for i in range(len(sfile['']['_rlnCoordinateX'])):
+        c = 1
+        if '_rlnAutopickFigureOfMerit' in sfile['']:
+            c= sfile['']['_rlnAutopickFigureOfMerit'][i]
         box = BoundBox(
             x=sfile['']['_rlnCoordinateX'][i]-box_width/2,
             y=sfile['']['_rlnCoordinateY'][i]-box_width/2,
             w=box_width,
             h=box_width,
-            c=sfile['']['_rlnAutopickFigureOfMerit'][i]
+            c=c
         )
 
 
@@ -308,6 +311,21 @@ def read_cbox_boxfile(path, min_dist_boxes_filament=0) -> Union[List[BoundBox],
     :param min_dist_boxes_filament: Minimum distance between filament boxes (in case it is filament)
     :return: Either a list of bounding boxes or a list of filaments.
     """
+    args_box_mapping = {
+        '_CoordinateX': "x",
+        '_CoordinateY': "y",
+        '_CoordinateZ': 'z',
+        '_Width': 'w',
+        '_Height': 'h',
+        '_Confidence': 'c',
+        '_Depth': 'depth',
+    }
+    args_meta_mapping = {
+        '_EstWidth': 'est_box_size',
+        '_EstHeight': 'est_box_size',
+        '_NumBoxes': 'num_boxes',
+        '_Angle': "angle"
+    }
     try:
         starfile = star.StarFile(path)
         boxes = []
@@ -315,22 +333,32 @@ def read_cbox_boxfile(path, min_dist_boxes_filament=0) -> Union[List[BoundBox],
         if 'cryolo' in starfile:
             is_filament = '_filamentid' in starfile['cryolo']
             for i in range(len(starfile['cryolo']['_CoordinateX'])):
-                box = BoundBox(x=starfile['cryolo']['_CoordinateX'][i],
-                               y=starfile['cryolo']['_CoordinateY'][i],
-                               z=starfile['cryolo']['_CoordinateZ'][i],
-                               w=starfile['cryolo']['_Width'][i],
-                               h=starfile['cryolo']['_Height'][i],
-                               c=starfile['cryolo']['_Confidence'][i],
-                               depth=starfile['cryolo']['_Depth'][i]
-                               )
-                if starfile['cryolo']["_EstWidth"][i] is not None and \
-                        starfile['cryolo']["_EstHeight"][i] is not None:
-                    box.meta["est_box_size"] = (starfile['cryolo']["_EstWidth"][i],
-                                                      starfile['cryolo']["_EstHeight"][i])
-                if starfile['cryolo']["_NumBoxes"][i] is not None:
-                    box.meta["num_boxes"] = starfile['cryolo']["_NumBoxes"][i]
-                if "_Angle" in starfile['cryolo'] and starfile['cryolo']["_Angle"][i] is not None:
-                    box.meta["angle"] = starfile['cryolo']["_Angle"][i]
+
+                kwargs = {}
+                for arg in args_box_mapping:
+                    if arg in starfile['cryolo']:
+                        if starfile['cryolo'][arg][i] is None or np.isnan(starfile['cryolo'][arg][i]):
+                            continue
+                        kwargs[args_box_mapping[arg]] = starfile['cryolo'][arg][i]
+
+                box = BoundBox(**kwargs)
+
+                for arg in args_meta_mapping:
+                    if arg in starfile['cryolo']:
+
+                        if starfile['cryolo'][arg][i] is None or np.isnan(starfile['cryolo'][arg][i]):
+                            continue
+                        if args_meta_mapping[arg] in box.meta:
+                            try:
+                                box.meta[args_meta_mapping[arg]].extend(starfile['cryolo'][arg][i])
+                            except Exception:
+                                l = [box.meta[args_meta_mapping[arg]]]
+                                l.append(starfile['cryolo'][arg][i])
+                                box.meta[args_meta_mapping[arg]] = l
+                        else:
+
+                            box.meta[args_meta_mapping[arg]] = starfile['cryolo'][arg][i]
+
                 if is_filament:
                     fid = int(starfile['cryolo']['_filamentid'][i])
                     if fid in filaments:
