@@ -23,10 +23,6 @@ def config_boxmanager_parser(parser_config):
         "--wildcard", help="Wildcard for selecting specific images (e.g *_new_*.mrc)"
     )
 
-    config_required_group.add_argument("-t", "--is_tomo_dir", action="store_true",
-                           help="Flag for specifying that the directory contains tomograms.")
-
-
 
 def config_configuration_parser(parser_config):
     config_required_group = parser_config.add_argument_group(
@@ -431,9 +427,20 @@ def main():
 
         evaluation.main(args)
     elif "boxmanager" in sys.argv[1]:
-        from cryoloBM import boxmanager
 
-        boxmanager.start_boxmanager(args.image_dir, args.box_dir, args.wildcard, is_tomo=args.is_tomo_dir)
+        import os
+        cmd = "napari_boxmanager"
+        if args.image_dir:
+            if args.wildcard:
+                args.image_dir = os.path.join(args.image_dir,args.wildcard)
+            cmd = cmd + f" '{args.image_dir}'"
+        if args.box_dir:
+            cmd = cmd + f" '{args.box_dir}'"
+        os.system(cmd)
+
+        #from cryoloBM import boxmanager
+
+        #boxmanager.start_boxmanager(args.image_dir, args.box_dir, args.wildcard, is_tomo=args.is_tomo_dir)
 
 
 def _main_():
